@@ -22,6 +22,7 @@
 #
 """Interfaces for handling BIDS-like neuroimaging structures."""
 from collections import defaultdict
+from contextlib import suppress
 from json import dumps, loads
 from pathlib import Path
 import shutil
@@ -55,7 +56,7 @@ from ..utils.misc import _copy_any, unlink
 
 regz = re.compile(r"\.gz$")
 _pybids_spec = loads(Path(_pkgres("niworkflows", "data/nipreps.json")).read_text())
-BIDS_DERIV_ENTITIES = frozenset({e["name"] for e in _pybids_spec["entities"]})
+BIDS_DERIV_ENTITIES = _pybids_spec["entities"]
 BIDS_DERIV_PATTERNS = tuple(_pybids_spec["default_path_patterns"])
 
 STANDARD_SPACES = tf.api.templates()
@@ -498,7 +499,8 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
     output_spec = _DerivativesDataSinkOutputSpec
     out_path_base = "niworkflows"
     _always_run = True
-    _config_entities = BIDS_DERIV_ENTITIES
+    _config_entities = frozenset({e["name"] for e in BIDS_DERIV_ENTITIES})
+    _config_entities_dict = BIDS_DERIV_ENTITIES
     _standard_spaces = STANDARD_SPACES
     _file_patterns = BIDS_DERIV_PATTERNS
     _default_dtypes = DEFAULT_DTYPES
@@ -526,7 +528,7 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
             setattr(self.inputs, k, inputs[k])
 
     def _run_interface(self, runtime):
-        from bids.layout import parse_file_entities
+        from bids.layout import parse_file_entities, Config
         from bids.layout.writing import build_path
         from bids.utils import listify
 
@@ -549,8 +551,16 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
             self._metadata = meta
 
         # Initialize entities with those from the source file.
+        custom_config = Config(
+            name="custom",
+            entities=self._config_entities_dict,
+            default_path_patterns=self._file_patterns,
+        )
         in_entities = [
-            parse_file_entities(str(relative_to_root(source_file)))
+            parse_file_entities(
+                str(relative_to_root(source_file)),
+                config=["bids", "derivatives", custom_config],
+            )
             for source_file in self.inputs.source_file
         ]
         out_entities = {k: v for k, v in in_entities[0].items()
@@ -648,9 +658,10 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
             # still None when it's time to write, just copy.
             new_data, new_header = None, None
 
-            is_nifti = out_file.name.endswith(
-                (".nii", ".nii.gz")
-            ) and not out_file.name.endswith((".dtseries.nii", ".dtseries.nii.gz"))
+            is_nifti = False
+            with suppress(nb.filebasedimages.ImageFileError):
+                is_nifti = isinstance(nb.load(orig_file), nb.Nifti1Image)
+
             data_dtype = self.inputs.data_dtype or self._default_dtypes[self.inputs.suffix]
             if is_nifti and any((self.inputs.check_hdr, data_dtype)):
                 nii = nb.load(orig_file)
